altos: Require manual flight erasing.
[fw/altos] / src / ao.h
index 58659af578416754a95bc99872959405eb796352..f23e4134ac0e9713208ceed47968fc312cb6399d 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -69,10 +69,6 @@ ao_sleep(__xdata void *wchan);
 void
 ao_wakeup(__xdata void *wchan);
 
-/* Wake up a specific task */
-void
-ao_wake_task(__xdata struct ao_task *task);
-
 /* set an alarm to go off in 'delay' ticks */
 void
 ao_alarm(uint16_t delay);
@@ -434,42 +430,44 @@ void
 ao_mutex_put(__xdata uint8_t *ao_mutex) __reentrant;
 
 /*
- * ao_ee.c
+ * Storage interface, provided by one of the eeprom or flash
+ * drivers
  */
 
-/*
- * We reserve the last block on the device for
- * configuration space. Writes and reads in this
- * area return errors.
- */
+/* Total bytes of available storage */
+extern __xdata uint32_t        ao_storage_total;
+
+/* Block size - device is erased in these units. At least 256 bytes */
+extern __xdata uint32_t        ao_storage_block;
 
-#define AO_EE_BLOCK_SIZE       ((uint16_t) (256))
-#define AO_EE_DEVICE_SIZE      ((uint32_t) 128 * (uint32_t) 1024)
-#define AO_EE_DATA_SIZE                (AO_EE_DEVICE_SIZE - (uint32_t) AO_EE_BLOCK_SIZE)
-#define AO_EE_CONFIG_BLOCK     ((uint16_t) (AO_EE_DATA_SIZE / AO_EE_BLOCK_SIZE))
+/* Byte offset of config block. Will be ao_storage_block bytes long */
+extern __xdata uint32_t        ao_storage_config;
 
+#define AO_STORAGE_ERASE_LOG   (ao_storage_config + AO_CONFIG_MAX_SIZE)
+
+/* Initialize above values. Can only be called once the OS is running */
 void
-ao_ee_flush(void) __reentrant;
+ao_storage_setup(void);
 
-/* Write to the eeprom */
-uint8_t
-ao_ee_write(uint32_t pos, uint8_t *buf, uint16_t len) __reentrant;
+/* Flush any pending write data */
+void
+ao_storage_flush(void) __reentrant;
 
-/* Read from the eeprom */
+/* Write data. Returns 0 on failure, 1 on success */
 uint8_t
-ao_ee_read(uint32_t pos, uint8_t *buf, uint16_t len) __reentrant;
+ao_storage_write(uint32_t pos, __xdata void *buf, uint16_t len) __reentrant;
 
-/* Write the config block (at the end of the eeprom) */
+/* Read data. Returns 0 on failure, 1 on success */
 uint8_t
-ao_ee_write_config(uint8_t *buf, uint16_t len) __reentrant;
+ao_storage_read(uint32_t pos, __xdata void *buf, uint16_t len) __reentrant;
 
-/* Read the config block (at the end of the eeprom) */
+/* Erase a block of storage. This always clears ao_storage_block bytes */
 uint8_t
-ao_ee_read_config(uint8_t *buf, uint16_t len) __reentrant;
+ao_storage_erase(uint32_t pos);
 
/* Initialize the EEPROM code */
 void
-ao_ee_init(void);
+ao_storage_init(void);
 
 /*
  * ao_log.c
@@ -740,6 +738,19 @@ void
 ao_serial_init(void);
 #endif
 
+/*
+ * ao_spi.c
+ */
+
+void
+ao_spi_send(void __xdata *block, uint16_t len) __reentrant;
+
+void
+ao_spi_recv(void __xdata *block, uint16_t len) __reentrant;
+
+void
+ao_spi_init(void);
+
 /*
  * ao_gps.c
  */
@@ -988,9 +999,14 @@ struct ao_config {
 
 extern __xdata struct ao_config ao_config;
 
+#define AO_CONFIG_MAX_SIZE     128
+
 void
 ao_config_get(void);
 
+void
+ao_config_put(void);
+
 void
 ao_config_init(void);
@@ -434,42 +430,44 @@ void
 
-/* Initialize the EEPROM code */
+/* Initialize the storage code */
 void